Skip to contents

Returns the names of all organisms available in the bundled gene database. These are the valid values for the organism parameter in functions like tcrdist_matrix and TCRrep.

Usage

list_organisms()

Value

A character vector of organism names, sorted alphabetically.

Examples

list_organisms()
#> [1] "human"     "human_gd"  "human_ig"  "mouse"     "mouse_gd"  "mouse_ig" 
#> [7] "rhesus"    "rhesus_gd"