Strict CDR3 sequence matching against a database
Source:R/tcr_db_matching.R
strict_single_chain_match_tcrs_to_db.RdFinds database entries where the CDR3alpha or CDR3beta amino acid sequence exactly matches a query TCR.
R/tcr_db_matching.R
strict_single_chain_match_tcrs_to_db.RdFinds database entries where the CDR3alpha or CDR3beta amino acid sequence exactly matches a query TCR.