Returns the names of all organisms available in the bundled gene
database. These are the valid values for the organism parameter
in functions like tcrdist_matrix and TCRrep.
Returns the names of all organisms available in the bundled gene
database. These are the valid values for the organism parameter
in functions like tcrdist_matrix and TCRrep.