Renders gene names as stacked text glyphs with heights proportional to their frequency — a "sequence logo" style for gene usage. Each gene name is rendered as a coloured raster image and vertically stacked so that more frequent genes occupy more vertical space.
Examples
if (FALSE) { # \dontrun{
data(dash)
pa <- dash[dash$epitope == "PA", ]
plot_vj_gene_logo(pa$vb, organism = "mouse", gene_type = "V",
chain = "beta")
plot_vj_gene_logo(pa$ja, organism = "mouse", gene_type = "J",
chain = "alpha")
} # }