Imports a beta-chain TCR repertoire from an Adaptive ImmunoSeq export file (TSV). Gene names are converted from Adaptive naming to IMGT format and optionally normalized to include an allele suffix.
Value
A data.frame with columns vb, jb,
cdr3b, and optionally count. Gene names are in IMGT
format. Rows with empty or NA CDR3 sequences are removed.
Details
Two column naming conventions are supported automatically:
- Convention 1 (newer)
vGeneName,jGeneName,aminoAcid,count- Convention 2 (older)
v_resolved(orvFamilyName),j_resolved(orjFamilyName),aminoAcid,count/templates/reads