Reverses a nucleotide sequence and replaces each base with its complement
using BASE_PARTNER. Supports standard bases (a/c/g/t, A/C/G/T),
IUPAC ambiguity codes, and the gap character (".").
Reverses a nucleotide sequence and replaces each base with its complement
using BASE_PARTNER. Supports standard bases (a/c/g/t, A/C/G/T),
IUPAC ambiguity codes, and the gap character (".").